@@ -301,9 +301,9 @@ test_that('get methods returns the correct object', {
   expect_true(tibble::is_tibble(foo_species_md))
   expect_true(tibble::is_tibble(foo_plant_md))
   expect_true(tibble::is_tibble(foo_env_md))
-  expect_is(foo_timestamp, 'POSIXct')
+  expect_s3_class(foo_timestamp, 'POSIXct')
   expect_identical(attr(foo_timestamp, 'tz'), 'Etc/GMT+3')
-  expect_is(foo_solar_timestamp, 'POSIXct')
+  expect_s3_class(foo_solar_timestamp, 'POSIXct')
   expect_identical(attr(foo_solar_timestamp, 'tz'), 'UTC')
   expect_true(is.character(foo_si_code))
 
@@ -377,8 +377,8 @@ test_that('get methods returns the correct object', {
   expect_true('TIMESTAMP' %in% names(multi_env_flags_solar[[1]]))
   expect_true(rlang::is_list(multi_timestamp, 3))
   expect_true(rlang::is_list(multi_solar_timestamp, 3))
-  expect_is(multi_timestamp[[1]], 'POSIXct')
-  expect_is(multi_solar_timestamp[[1]], 'POSIXct')
+  expect_s3_class(multi_timestamp[[1]], 'POSIXct')
+  expect_s3_class(multi_solar_timestamp[[1]], 'POSIXct')
   expect_true(rlang::is_list(multi_si_code, 3))
   expect_true(rlang::is_character(multi_si_code[[1]]))
   expect_true(rlang::is_list(multi_site_md, 3))
